"""这是nester模块，提供了一个print_lol()的函数。"""

def print_lol(the_list, level=0):
    """这个函数取一个位置函数，名为“the_list”。"""
    for each_item in the_list:
        if isinstance(each_item, list):
            print_lol(each_item)
        else:
            for tab_stop in range(level):
                print("\t", end='')
            print(each_item)



# from distutils.core import setuppyt
from setuptools import setup, find_packages

setup(
    name         = 'ivnester',
    version      = '1.1.0',
    license      = 'MIT License',
    install_requires = [],
    include_package_data = True,
    packages     = ['ivnester'],
    author       = 'ivnstar',
    author_email = '44828299@qq.com',
    url          = 'http://www.ivnature.cn',
    description  = 'A simple printer of nested lists',
)